@@ -116,7 +116,7 @@ class CogniteGeospatialClient:
         port: int = None,
         api_token: str = None,
         project: str = None,
-        timeout: int = 60000,
+        timeout: int = 600,  # seconds
     ):
         # configure env
         api_key = api_key or os.getenv("COGNITE_API_KEY")
@@ -146,6 +146,7 @@ class CogniteGeospatialClient:
             raise ValueError("Project must be provided")
 
         api_client = cognite.geospatial.internal.ApiClient(self.configuration)
+        api_client.user_agent = "Cognite-SDK/python"
         self.api = cognite.geospatial.internal.SpatialApi(api_client)
         self.timeout = timeout
         self._make_new_loop()
@@ -220,7 +221,7 @@ class CogniteGeospatialClient:
         """
         spatial_by_ids = _create_spatial_ids(id, external_id)
         try:
-            response = yield self.api.by_ids_spatial_items(self.project, spatial_by_ids)
+            response = yield self.api.by_ids_spatial_items(self.project, spatial_by_ids, _request_timeout=self.timeout)
             return _first_item(response)
         except ApiException as e:
             _throw_exception(e)
@@ -238,7 +239,7 @@ class CogniteGeospatialClient:
         """
         spatial_delete_ids = _create_spatial_ids(id, external_id)
         try:
-            response = yield self.api.delete_spatial(self.project, spatial_delete_ids)
+            response = yield self.api.delete_spatial(self.project, spatial_delete_ids, _request_timeout=self.timeout)
             return _first_item(response)
         except ApiException as e:
             _throw_exception(e)
@@ -260,7 +261,7 @@ class CogniteGeospatialClient:
         elif external_id is not None:
             item = ExternalIdDTO(external_id=external_id)
 
-        spatial_item = yield self.get_spatial_info_async(id=id, external_id=external_id, project=self.project)
+        spatial_item = yield self.get_spatial_info_async(id=id, external_id=external_id)
         if spatial_item is None:
             return None
 
@@ -282,12 +283,14 @@ class CogniteGeospatialClient:
         )
 
         try:
-            response = yield self.api.get_spatial_items_data_names(self.project, item)
+            response = yield self.api.get_spatial_items_data_names(self.project, item, _request_timeout=self.timeout)
             if response is not None:
 
                 for data_item in response.items:
                     data_request = SpatialDataRequestDTO(spatial_id=item, name=data_item.name)
-                    data = yield self.api.get_spatial_items_data(self.project, data_request)
+                    data = yield self.api.get_spatial_items_data(
+                        self.project, data_request, _request_timeout=self.timeout
+                    )
                     if data is not None and len(data.items) > 0:
                         ditem = data.items[0]
                         byte_buffer = base64.urlsafe_b64decode(ditem.value)
@@ -324,7 +327,9 @@ class CogniteGeospatialClient:
         proj = _create_projection(projection)
         spatialite_projection = SpatialItemsProjectionDTO(ids=spatial_by_ids, projection=proj)
         try:
-            response = yield self.api.get_spatial_coverage(self.project, spatialite_projection)
+            response = yield self.api.get_spatial_coverage(
+                self.project, spatialite_projection, _request_timeout=self.timeout
+            )
             return _first_item(response)
         except ApiException as e:
             _throw_exception(e)
@@ -370,7 +375,9 @@ class CogniteGeospatialClient:
         )
 
         try:
-            response = yield self.api.search_spatial(self.project, spatial_search_request_dto=spatial_search_request)
+            response = yield self.api.search_spatial(
+                self.project, spatial_search_request_dto=spatial_search_request, _request_timeout=self.timeout
+            )
             if response is not None:
                 return response.items
             return None
@@ -427,7 +434,7 @@ class CogniteGeospatialClient:
             )
         else:
             spatial_filter = SpatialFilterObject(
-                "within_distance",
+                "withinDistance",
                 geometry=geometry,
                 projection=proj,
                 distance_meter=distance,
@@ -437,7 +444,9 @@ class CogniteGeospatialClient:
         spatial_search_request = SpatialSearchRequestDTO(limit=limit, spatial_filter=spatial_filter, crs=crs)
 
         try:
-            response = yield self.api.search_spatial(self.project, spatial_search_request_dto=spatial_search_request)
+            response = yield self.api.search_spatial(
+                self.project, spatial_search_request_dto=spatial_search_request, _request_timeout=self.timeout
+            )
             if response is not None:
                 return response.items
             return None
@@ -476,11 +485,13 @@ class CogniteGeospatialClient:
         geometry = self._create_geometry(id, external_id, geography)
         proj = _create_projection(projection)
         spatial_filter = SpatialFilterObject(
-            "completely_within", geometry, projection=proj, local_vars_configuration=self.configuration
+            "completelyWithin", geometry, projection=proj, local_vars_configuration=self.configuration
         )
         spatial_search_request = SpatialSearchRequestDTO(limit=limit, spatial_filter=spatial_filter, crs=crs)
         try:
-            response = yield self.api.search_spatial(self.project, spatial_search_request_dto=spatial_search_request)
+            response = yield self.api.search_spatial(
+                self.project, spatial_search_request_dto=spatial_search_request, _request_timeout=self.timeout
+            )
             if response is not None:
                 return response.items
             return None
@@ -527,7 +538,7 @@ class CogniteGeospatialClient:
 
         create_spatial_items = CreateSpatialItemsDTO(items=[spatial_item])
         try:
-            response = yield self.api.create_spatial(self.project, create_spatial_items)
+            response = yield self.api.create_spatial(self.project, create_spatial_items, _request_timeout=self.timeout)
             return _first_item(response)
         except ApiException as e:
             _throw_exception(e)
@@ -583,7 +594,7 @@ class CogniteGeospatialClient:
 
         create_spatial_items = CreateSpatialItemsDTO(items=[spatial_item])
         try:
-            response = yield self.api.create_spatial(self.project, create_spatial_items)
+            response = yield self.api.create_spatial(self.project, create_spatial_items, _request_timeout=self.timeout)
             if response is not None:
                 return response.items
             return None
@@ -646,7 +657,7 @@ class CogniteGeospatialClient:
         )
 
         try:
-            response = yield self.api.add_spatial_item_data(self.project, spatial_data)
+            response = yield self.api.add_spatial_item_data(self.project, spatial_data, _request_timeout=self.timeout)
             if response is not None:
                 return response.items
             return None
@@ -659,7 +670,9 @@ class CogniteGeospatialClient:
         """
         spatial_by_ids = _create_spatial_ids(id, external_id)
         try:
-            response = yield self.api.calculate_spatial_coverage(self.project, spatial_by_ids)
+            response = yield self.api.calculate_spatial_coverage(
+                self.project, spatial_by_ids, _request_timeout=self.timeout
+            )
             return response
         except ApiException as e:
             _throw_exception(e)
