@@ -28,7 +28,7 @@ class CogniteSeismicClient:
             raise ValueError(
                 "You have either not passed an api key or not set the COGNITE_API_KEY environment variable."
             )
-        self.base_url = base_url or "api-grpc.cognitedata.com"
+        self.base_url = base_url or "api.cognitedata.com"
         self.port = port or "443"
         self.url = self.base_url + ":" + str(self.port)
         self.metadata = [("api-key", self.api_key)]
